@@ -93,8 +93,33 @@ def cli(ctx: Context, private_key: str, chain_id: int) -> None:
     nargs=1,
     type=str,
 )
+@click.option(
+    "--max-gas-price",
+    "-mgp",
+    "max_gas_price",
+    help="maximum gas price used by reporter",
+    nargs=1,
+    type=int,
+    default=0,
+)
+@click.option(
+    "--profit",
+    "-p",
+    "profit_percent",
+    help="lower threshold (inclusive) for expected percent profit",
+    nargs=1,
+    type=float,
+    default=0.0,
+)
+@click.option("--submit-once/--submit-continuous", default=False)
 @click.pass_context
-def report(ctx: Context, legacy_id: str) -> None:
+def report(
+    ctx: Context,
+    legacy_id: str,
+    max_gas_price: int,
+    submit_once: bool,
+    profit_percent: float,
+) -> None:
     """Report values to Tellor oracle"""
 
     # Ensure valid legacy id
@@ -104,12 +129,20 @@ def report(ctx: Context, legacy_id: str) -> None:
         )
         return
 
-    click.echo(f"Reporting legacy ID: {legacy_id}")
-
     private_key = ctx.obj["PRIVATE_KEY"]
     chain_id = ctx.obj["CHAIN_ID"]
+    cfg.main.private_key = private_key
+    cfg.main.chain_id = chain_id
+
     endpoint = cfg.get_endpoint()
 
+    click.echo(f"Reporting legacy ID: {legacy_id}")
+    click.echo(f"Current chain ID: {chain_id}")
+    if profit_percent == 0.0:
+        click.echo("Reporter not enforcing profit threshold.")
+    else:
+        click.echo(f"Lower bound for expected percent profit: {profit_percent}%")
+
     master, oracle = get_tellor_contracts(
         private_key=private_key, endpoint=endpoint, chain_id=chain_id
     )
@@ -121,19 +154,15 @@ def report(ctx: Context, legacy_id: str) -> None:
         private_key=private_key,
         master=master,
         oracle=oracle,
-        datafeeds=[chosen_feed],
+        datafeed=chosen_feed,
+        profit_threshold=profit_percent,
+        max_gas_price=max_gas_price,
     )
 
-    receipts_statuses = asyncio.run(legacy_reporter.report_once())
-
-    for receipt, status in receipts_statuses:
-        if not status.ok:
-            logger.error(status.error)
-            return
-        if status.ok:
-            tx_hash = receipt["transactionHash"].hex()  # type: ignore
-            # Point to relevant explorer
-            logger.info(f"View reported data: \n{endpoint.explorer}/tx/{tx_hash}")
+    if submit_once:
+        _, _ = asyncio.run(legacy_reporter.report_once())
+    else:
+        _, _ = asyncio.run(legacy_reporter.report())
 
 
 if __name__ == "__main__":
